IIB operations
================

.. py:module:: pubtools._quay.iib_operations

These functions handle logic related to the common IIB operations. This includes contacting IIB, creating new signatures, removing old signatues, and and copying the new index image to the right location

Main entrypoint functions
-------------------------

.. autofunction:: task_iib_add_bundles
.. autofunction:: task_iib_remove_operators
.. autofunction:: task_iib_build_from_scratch
.. autofunction:: verify_target_settings
